@@ -13,6 +13,8 @@ MANUAL_FIELD_NAMES = {
     'statement_of_acceptance_transfer_cargo_id': 'StatementOfAcceptanceTransferCargoID',
     'recipient_full_name_ew': 'RecipientFullNameEW',
     'ref_ew': 'RefEW',
+    'block_international_sender_lkk': 'BlockInternationalSenderLKK',
+    'can_ew_transporter': 'CanEWTransporter',
 }
 
 
